@@ -18,7 +18,7 @@ import re
 from copy import deepcopy
 from functools import partial, reduce
 from itertools import chain
-from typing import List, Optional, Generator, Set, Union
+from typing import Generator, List, Optional, Set, Union
 
 import nltk
 from more_itertools import windowed
@@ -267,7 +267,7 @@ class PreProcessor(BasePreProcessor):
             for sen in sentences:
                 current_word_count = len(sen.split(" "))
                 if current_word_count > split_length:
-                    long_sentence_message = f"One or more sentence found with word count higher than the split length."
+                    long_sentence_message = "One or more sentence found with word count higher than the split length."
                     if long_sentence_message not in self.print_log:
                         self.print_log.add(long_sentence_message)
                         logger.warning(long_sentence_message)
